@@ -69,6 +69,8 @@ static void
 dump_test_enum_small (void)
 {
   TestMessRequiredEnumSmall es;
+  es.set_test(NEG_VALUE);
+  dump_message_bytes(&es, "test_enum_small_NEG_VALUE");
   es.set_test(VALUE);
   dump_message_bytes(&es, "test_enum_small_VALUE");
   es.set_test(OTHER_VALUE);
@@ -78,6 +80,8 @@ static void
 dump_test_enum_big (void)
 {
   TestMessRequiredEnum eb;
+  eb.set_test(VALUENEG123456); dump_message_bytes(&eb, "test_enum_big_VALUENEG123456");
+  eb.set_test(VALUENEG1); dump_message_bytes(&eb, "test_enum_big_VALUENEG1");
   eb.set_test(VALUE0); dump_message_bytes(&eb, "test_enum_big_VALUE0");
   eb.set_test(VALUE127); dump_message_bytes(&eb, "test_enum_big_VALUE127");
   eb.set_test(VALUE128); dump_message_bytes(&eb, "test_enum_big_VALUE128");
@@ -224,8 +228,12 @@ static void dump_test_required_uint64 (void)
   dump_message_bytes (&mess, "test_required_uint64_mill");
   mess.set_test (BILLION);
   dump_message_bytes (&mess, "test_required_uint64_bill");
+  mess.set_test (BILLION*20);
+  dump_message_bytes (&mess, "test_required_uint64_20_bill");
   mess.set_test (TRILLION);
   dump_message_bytes (&mess, "test_required_uint64_tril");
+  mess.set_test (TRILLION*20);
+  dump_message_bytes (&mess, "test_required_uint64_20_tril");
   mess.set_test (QUADRILLION);
   dump_message_bytes (&mess, "test_required_uint64_quad");
   mess.set_test (QUINTILLION);
@@ -298,6 +306,8 @@ static void dump_test_required_enum_small (void)
 static void dump_test_required_enum (void)
 {
   TestMessRequiredEnum mess;
+  mess.set_test (VALUENEG1);
+  dump_message_bytes (&mess, "test_required_enum_neg1");
   mess.set_test (VALUE0);
   dump_message_bytes (&mess, "test_required_enum_0");
   mess.set_test (VALUE1);
@@ -515,6 +525,8 @@ static void dump_test_optional_bool (void)
 static void dump_test_optional_enum_small (void)
 {
   TestMessOptional opt;
+  opt.set_test_enum_small (NEG_VALUE);
+  dump_message_bytes (&opt, "test_optional_enum_small_neg1");
   opt.set_test_enum_small (VALUE);
   dump_message_bytes (&opt, "test_optional_enum_small_0");
   opt.set_test_enum_small (OTHER_VALUE);
@@ -527,6 +539,8 @@ static void dump_test_optional_enum (void)
 //echo '    opt.set_test_enum (VALUE'$a');
 //dump_message_bytes (&opt, "test_optional_enum_'$a'");'
 //done
+    opt.set_test_enum (VALUENEG1);
+    dump_message_bytes (&opt, "test_optional_enum_neg1");
     opt.set_test_enum (VALUE0);
     dump_message_bytes (&opt, "test_optional_enum_0");
     opt.set_test_enum (VALUE1);
@@ -984,7 +998,7 @@ static void dump_test_packed_repeated_enum (void)
 static void dump_test_unknown_fields (void)
 {
   EmptyMess mess;
-  const google::protobuf::Message::Reflection *reflection = mess.GetReflection();
+  const google::protobuf::Reflection *reflection = mess.GetReflection();
   google::protobuf::UnknownFieldSet *fs = reflection->MutableUnknownFields(&mess);
 
 #if GOOGLE_PROTOBUF_VERSION >= 2001000
